;**************************************************************************
;*                                                                        *
;* Program     : 240128-A2                                                *
;* Title       : 240 column x 128 row LCD Graphic Module Driving Program  *
;*                                                                        *
;* MCU         : AT89C52, 12MHz                                           *
;* Programmer  : Stephen Yu, Aug. 2002                                    *
;* File name   : 240128a2.asm                                             *
;* Eval. Board : LKEB-G03-A                                               *
;* Description : Drive 240x128 LCD graphic module with LCD controller     *
;*               T6963C                                                   *
;* LCD Module  : LKG-240128-A2 or equivalent                              *
;* Assembler   : AD2500 or equivalent                                     *
;* Copyright   : Lcdmod Kit                                               *
;**************************************************************************

;***************************************
;*      MCU <-> LCM pin connection     *
;*                                     *
;* P1.0 - 1.7 <-> DB0 -DB7             *
;***************************************

FS      REG     P3.0
RST     REG     P3.1
CLICK   REG     P3.2
C/D     REG     P3.3
CE      REG     P3.4
RD      REG     P3.5
WR      REG     P3.6

COM     EQU     32H
DAT1    EQU     30H
DAT2    EQU     31H
MARK    EQU     33H
O_Y     EQU     35H
O_X     EQU     36H
COUNT   EQU     34H
TEMP1   EQU     37H
TEMP2   EQU     38H
TEMP3   EQU     39H
TEMP4   EQU     3AH

        ORG     00H
START:
        SETB    RST          ;
        CLR     FS           ; SET FONT TO 8x8
        CLR     CE           ; CHIP ENABLE
        LCALL   INIT         ; CONTROLLER INITIALIZATION
MAIN:
        LCALL   ALL_ON       ; ALL PIXEL ON
        CALL    BUTTON

        LCALL   ALL_OFF      ; ALL PIXEL OFF
        CALL    BUTTON

        MOV     COM,#98H     ; ALTERNATE COLUMN ON
        LCALL   C_DW2
        MOV     O_X,#00H
        MOV     O_Y,#00H
        LCALL   COLUMN
        LCALL   BUTTON

        MOV     COM,#98H     ; ALTERNATE ROW ON
        LCALL   C_DW2
        MOV     O_X,#00H     ; X COOR = 0
        MOV     O_Y,#00H     ; Y COOR = 0
        LCALL   ROW
        LCALL   BUTTON

        MOV     COM,#98H     ; 1x1 CHECKER BOARD
        LCALL   C_DW2
        MOV     O_X,#00H     ; X COOR = 0
        MOV     O_Y,#00H     ; Y COOR = 0
        LCALL   S_CHECKER
        LCALL   BUTTON

        MOV     COM,#98H     ; 2x2 CHECKER BOARD
        LCALL   C_DW2
        MOV     O_X,#00H     ; X COOR = 0
        MOV     O_Y,#00H     ; Y COOR = 0
        LCALL   M_CHECKER
        LCALL   BUTTON

        MOV     COM,#98H     ; 4x4 CHECKER BOARD
        LCALL   C_DW2
        MOV     O_X,#00H     ; X COOR = 0
        MOV     O_Y,#00H     ; Y COOR = 0
        LCALL   B_CHECKER
        LCALL   BUTTON

        MOV     COM,#98H     ; DISPLAY AN IMAGE
        LCALL   C_DW2
        MOV     O_X,#00H     ; X COOR = 0
        MOV     O_Y,#00H     ; Y COOR = 0
        LCALL   GRAPH
        LCALL   BUTTON

        JMP     MAIN

INIT:                        ; ( PROCEDRUE FOR INITIALIZATION )
        MOV     DAT1,#00H
        MOV     DAT2,#00H
        MOV     COM,#40H     ; SET TEXT HOME ADDRESS TO 0000H
        LCALL   C_DW
        MOV     DAT1,#20H
        MOV     DAT2,#00H
        MOV     COM,#41H     ; SET TEXT AREA TO 32 COLUMNS
        LCALL   C_DW
        MOV     DAT1,#00H
        MOV     DAT2,#08H
        MOV     COM,#42H     ; SET GRAPHIC HOME ADDRESS TO 0800H
        LCALL   C_DW
        MOV     DAT1,#20H
        MOV     DAT2,#00H
        MOV     COM,#43H     ; SET GRAPHIC AREA TO 32 COLUMNS
        LCALL   C_DW
        MOV     COM,#0A7H    ; SET CURSOR TO 8-LINE CURSOR
        LCALL   C_DW2
        MOV     COM,#80H     ; DISPLAY MODE AS "OR" MODE
        LCALL   C_DW2
        MOV     COM,#9CH     ; TEXT ON, GRAPHIC ON, CURSOR DISPLAY OFF, CURSOR BLINK OFF
        LCALL   C_DW2
        RET

ALL_OFF:                     ; ( PROCEDRUE FOR PIXEL OFF )
        MOV     DAT1,#00H
        MOV     DAT2,#00H
        MOV     COM,#24H     ; SET ADDRESS POINTER TO 0000H
        LCALL   C_DW
        MOV     R3,#00H      ; SET Y COUNTER = 256
        MOV     R4,#20H      ; SET X COUNTER = 32
        MOV     COM,#0B0H    ; SET DATA AUTO WRITE
        LCALL   C_DW2
ALL_OFF1:
        LCALL   CS_3
        MOV     A,#00H       ; PUT 00000000 TO DATA BYTE
        LCALL   C_DW3
        DJNZ    R3,ALL_OFF1
        DJNZ    R4,ALL_OFF1
        MOV     COM,#0B2H    ; RESET AUTO
        LCALL   C_DW2
        RET

ALL_ON:                      ; ( PROCEDRUE FOR PIXEL ON )
        MOV     DAT1,#00H
        MOV     DAT2,#00H
        MOV     COM,#24H     ; SET ADDRESS POINTER TO 0000H
        LCALL   C_DW
        MOV     R3,#00H      ; SET Y COUNTER = 256
        MOV     R4,#20H      ; SET X COUNTER = 32
        MOV     COM,#0B0H    ; SET DATA AUTO WRITE
        LCALL   C_DW2
ALL_ON1:
        LCALL   CS_3
        MOV     A,#FFH       ; PUT 11111111 TO DATA BYTE
        LCALL   C_DW3
        DJNZ    R3,ALL_ON1
        DJNZ    R4,ALL_ON1
        MOV     COM,#0B2H    ; RESET AUTO
        LCALL   C_DW2
        RET

COLUMN:                      ; ( PROCEDRUE FOR ALTERNATE COLUMN ON )
        MOV     TEMP1,O_Y
        MOV     TEMP2,O_X
        MOV     R3,#128      ; SET Y COUNTER = 128
COLUMN1:
        MOV     A,O_Y        ; CALCULATE THE RAM ADDRESS
        MOV     B,#20H
        MUL     AB
        ADD     A,O_X
        MOV     O_X,A
        MOV     A,B
        ADDC    A,#08H
        MOV     O_Y,A
        MOV     R4,#32       ; SET X COUNTER = 32
COLUMN2:
        MOV     DAT1,O_X
        MOV     DAT2,O_Y
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW

        MOV     DAT2,#AAH    ; PUT 10101010 TO DATA BYTE
        MOV     COM,#0C0H    ; DATA WRITE AND INCREMENT ADDRESS POINTER
        LCALL   C_DW1

        MOV     A,O_X        ; RE-CALCULATE THE RAM ADDRESS
        INC     A
        MOV     O_X,A
        DJNZ    R4,COLUMN2

        MOV     A,TEMP1
        INC     A
        MOV     TEMP1,A
        MOV     O_Y,TEMP1
        MOV     O_X,TEMP2
        DJNZ    R3,COLUMN1
        RET

ROW:                         ; ( PROCEDRUE FOR ALTERNATE ROW ON )
        MOV     TEMP1,O_Y
        MOV     TEMP2,O_X
        MOV     R3,#64       ; SET Y COUNTER = 64
ROW1:
        MOV     A,O_Y        ; CALCULATE THE RAM ADDRESS
        MOV     B,#20H
        MUL     AB
        ADD     A,O_X
        MOV     O_X,A
        MOV     A,B
        ADDC    A,#08H
        MOV     O_Y,A

        MOV     R4,#32       ; SET X COUNTER = 32
ROW2:
        MOV     DAT1,O_X
        MOV     DAT2,O_Y
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW

        MOV     DAT2,#FFH    ; PUT 11111111 TO DATA BYTE
        MOV     COM,#0C0H    ; DATA WRITE AND INCREMENT ADDRESS POINTER
        LCALL   C_DW1

        MOV     A,O_X        ; RE-CALCULATE THE RAM ADDRESS
        INC     A
        MOV     O_X,A
        DJNZ    R4,ROW2

        MOV     A,TEMP1
        INC     A
        MOV     TEMP1,A
        MOV     O_Y,TEMP1

        MOV     O_X,TEMP2

        MOV     R4,#32       ; RE-SET X COUNTER = 32
ROW3:
        MOV     A,O_Y        ; RE-CALCULATE THE RAM ADDRESS
        MOV     B,#20H
        MUL     AB
        ADD     A,O_X
        MOV     O_X,A
        MOV     A,B
        ADDC    A,#08H
        MOV     O_Y,A

ROW4:
        MOV     DAT1,O_X
        MOV     DAT2,O_Y
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW

        MOV     DAT2,#00H    ; PUT 00000000 TO DATA BYTE
        MOV     COM,#0C0H    ; DATA WRITE AND INCREMENT ADDRESS POINTER
        LCALL   C_DW1

        MOV     A,O_X        ; RE-CALCULATE THE RAM ADDRESS
        INC     A
        MOV     O_X,A
        DJNZ    R4,ROW4

        MOV     A,TEMP1
        INC     A
        MOV     TEMP1,A
        MOV     O_Y,TEMP1

        MOV     O_X,TEMP2
        DJNZ    R3,ROW1
        RET

S_CHECKER:                   ; ( PROCEDRUE FOR 1x1 CHEKER BOARD )
        MOV     TEMP1,O_Y
        MOV     TEMP2,O_X
        MOV     R3,#64       ; SET Y COUNTER = 64
S_CHECKER1:
        MOV     A,O_Y        ; CALCULATE THE RAM ADDRESS
        MOV     B,#20H
        MUL     AB
        ADD     A,O_X
        MOV     O_X,A
        MOV     A,B
        ADDC    A,#08H
        MOV     O_Y,A

        MOV     R4,#32       ; SET X COUNTER = 32
S_CHECKER2:
        MOV     DAT1,O_X
        MOV     DAT2,O_Y
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW

        MOV     DAT2,#AAH    ; PUT 10101010 TO DATA BYTE
        MOV     COM,#0C0H    ; DATA WRITE AND INCREMENT ADDRESS POINTER
        LCALL   C_DW1

        MOV     A,O_X        ; RE-CALCULATE THE RAM ADDRESS
        INC     A
        MOV     O_X,A
        DJNZ    R4,S_CHECKER2

        MOV     A,TEMP1
        INC     A
        MOV     TEMP1,A
        MOV     O_Y,TEMP1

        MOV     O_X,TEMP2

        MOV     R4,#32       ; RE-SET X COUNTER = 32
S_CHECKER3:
        MOV     A,O_Y        ; RE-CALCULATE THE RAM ADDRESS
        MOV     B,#20H
        MUL     AB
        ADD     A,O_X
        MOV     O_X,A
        MOV     A,B
        ADDC    A,#08H
        MOV     O_Y,A

S_CHECKER4:
        MOV     DAT1,O_X
        MOV     DAT2,O_Y
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW

        MOV     DAT2,#55H    ; PUT 01010101 TO DATA BYTE
        MOV     COM,#0C0H    ; DATA WRITE AND INCREMENT ADDRESS POINTER
        LCALL   C_DW1

        MOV     A,O_X        ; RE-CALCULATE THE RAM ADDRESS
        INC     A
        MOV     O_X,A
        DJNZ    R4,S_CHECKER4

        MOV     A,TEMP1
        INC     A
        MOV     TEMP1,A
        MOV     O_Y,TEMP1

        MOV     O_X,TEMP2
        DJNZ    R3,S_CHECKER1
        RET

M_CHECKER:                   ; ( PROCEDRUE FOR 2x2 CHEKER BOARD )
        MOV     DAT1,O_X     ; CALCULATE THE RAM ADDRESS
        MOV     A,O_Y
        ADD     A,#08H
        MOV     DAT2,A
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW
        MOV     R3,#32       ; SET Y COUNTER = 32
        MOV     R4,#64       ; SET X COUTNER = 64
        MOV     COM,#0B0H    ; SET DATA AUTO WRITE
        LCALL   C_DW2
M_CHECKER1:
        LCALL   CS_3
        MOV     A,#CCH       ; PUT 11001100 TO DATA BYTE
        LCALL   C_DW3
        DJNZ    R4,M_CHECKER1
        MOV     R4,#64       ; RE-SET X COUNTER = 64
M_CHECKER2:
        LCALL   CS_3
        MOV     A,#33H       ; PUT 00110011 TO DATA BYTE
        LCALL   C_DW3
        DJNZ    R4,M_CHECKER2
        MOV     R4,#64       ; RE-SET X OOUTNER = 64
        DJNZ    R3,M_CHECKER1
        MOV     COM,#0B2H    ; RESET AUTO
        LCALL   C_DW2
        RET

B_CHECKER:                   ; ( PROCEDRUE FOR 4x4 CHEKER BOARD )
        MOV     DAT1,O_X
        MOV     A,O_Y
        ADD     A,#08H
        MOV     DAT2,A
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW
        MOV     R3,#16       ; SET Y COUNTER = 16
        MOV     R4,#128      ; SET X XOUNTER = 128
        MOV     COM,#0B0H    ; SET DATA AUTO WRITE
        LCALL   C_DW2
B_CHECKER1:
        LCALL   CS_3
        MOV     A,#F0H       ; PUT 11110000 TO DATA BYTE
        LCALL   C_DW3
        DJNZ    R4,B_CHECKER1
        MOV     R4,#128      ; RE-SET X COUTNER = 128
B_CHECKER2:
        LCALL   CS_3
        MOV     A,#0FH       ; PUT 00001111 TO DATA BYTE
        LCALL   C_DW3
        DJNZ    R4,B_CHECKER2
        MOV     R4,#128      ; RE-SET X COUNTER = 128
        DJNZ    R3,B_CHECKER1
        MOV     COM,#0B2H    ; RESET AUTO
        LCALL   C_DW2
        RET

GRAPH:                       ; ( PROCEDRUE FOR DISPLAY IMAGE )
        MOV     A,O_Y
        MOV     B,#20H       ; CALCULATE THE RAM ADDRESS
        MUL     AB
        ADD     A,O_X
        MOV     O_X,A
        MOV     A,B
        ADDC    A,#08H
        MOV     O_Y,A
        MOV     DAT1,O_X
        MOV     DAT2,O_Y
        MOV     DPTR,#IMG
        MOV     COM,#24H     ; SET ADDRESS POINTER
        LCALL   C_DW


        MOV     R3,#128
        MOV     R4,#30       ; SET X COUNTER = 30
        MOV     COM,#0B0H
        LCALL   C_DW2
GRAPH1:
        LCALL   CS_3
        CLR     A
        MOVC    A,@A + DPTR  ; GET THE IMAGE DATA
        LCALL   FLIP         ; FLIP THE IMAGE DATA BTYE
        LCALL   C_DW3
        INC     DPTR
        DJNZ    R4,GRAPH1
        MOV     R4,#30       ; RE-SET THE X COUNTER = 30

        LCALL   CS_3
        MOV     A,#FFH       ; PUT 1111111 DATA BYTE IN LAST TWO COLUMN
        LCALL   C_DW3
        LCALL   CS_3
        MOV     A,#FFH
        LCALL   C_DW3
        DJNZ    R3,GRAPH1

        MOV     COM,#0B2H    ; RESET AUTO
        LCALL   C_DW2
        RET

C_DW:                        ; 2 DATA AND 1 COMMAND WRITE
        LCALL   CS
        MOV     A,DAT1
        LCALL   C_DW3
C_DW1:                       ; 1 DATA AND 1 COMMAND WRITE
        LCALL   CS
        MOV     A,DAT2
        LCALL   C_DW3
C_DW2:                       ; 1 COMMNAD WRITE ONLY
        LCALL   CS
        MOV     A,COM
        LJMP    C_DW4
C_DW3:
        CLR     C/D          ; COMMAND OR DATA SELECTION
C_DW4:
        MOV     P1,A
        CLR     WR
        SETB    WR
        RET

CS:                          ; CHECK STATUS
        LCALL   R_STATUS
        JNB     ACC.0,CS     ; CHECK COMMAND EXECUTION CAPABILITY
        JNB     ACC.1,CS     ; CHECK DATA READ / WRITE CAPABILITY
        RET

CS_2:
        LCALL   R_STATUS
        JNB     ACC.2,CS_2   ; CHECK AUTO MODE DATA READ CAPABILITY
        RET

CS_3:
        LCALL   R_STATUS
        JNB     ACC.3,CS_3   ; CHECK AUTO MODE DATA WRITE CAPABILITY
        RET

R_STATUS:
        MOV     P1,#0FFH     ; READ THE STATUS
        SETB    C/D
        CLR     RD
        MOV     A,P1
        SETB    RD
        RET

BUTTON: JB      CLICK,$      ; ( PROCEDURE FOR DETECT CLICKING OF PUSH BUTTON )
        ACALL   WAIT         ; ESCAPE FROM THE DEBOUNCING OF BUTTON
        JNB     CLICK,$
        ACALL   WAIT
        RET

FLIP:
        PUSH    7
        MOV     R7,#8
FLIP1:
        RLC     A
        MOV     TEMP3,A
        MOV     A,TEMP4
        RRC     A
        MOV     TEMP4,A
        MOV     A,TEMP3
        DJNZ    R7,FLIP1
        MOV     A,TEMP4
        POP     7
        RET

DELAY:                       ; ( PROCEDURE FOR TIME DELAY )
        PUSH    5
        PUSH    6
        PUSH    7
        MOV     R5,#150
DL1:    MOV     R6,#20
DL2:    MOV     R7,#50
DL3:    DJNZ    R7,DL3
        DJNZ    R6,DL2
        DJNZ    R5,DL1
        POP     7
        POP     6
        POP     5
        RET

WAIT:                        ; ( PROCEDURE FOR TIME WAITING )
        PUSH    6
        PUSH    7
        MOV     R6,#100
WAIT2:  MOV     R7,#200
        DJNZ    R7,$
        DJNZ    R6,WAIT2
        POP     7
        POP     6
        RET

IMG:    DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,40H,10H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,20H,10H,04H,00H,20H;
        DB 08H,00H,00H,00H,01H,40H,00H,00H;
        DB 05H,04H,01H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,20H,10H,04H,00H,20H,08H,00H;
        DB 00H,00H,01H,40H,00H,00H,05H,00H;
        DB 01H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,E0H;
        DB 78H,9EH,43H,10H,44H,55H,55H,00H;
        DB E1H,70H,8FH,C3H,25H,84H,07H,38H;
        DB CEH,03H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,20H,11H,84H;
        DB 04H,10H,44H,55H,55H,00H,11H,49H;
        DB 55H,24H,15H,04H,01H,44H,51H,05H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,20H,11H,84H,04H,08H;
        DB 42H,55H,55H,00H,11H,48H,55H,24H;
        DB 1DH,04H,01H,04H,51H,05H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,F8H,03H;
        DB 00H,20H,11H,84H,04H,08H,82H,A2H;
        DB 28H,00H,11H,49H,55H,24H,25H,04H;
        DB 01H,44H,51H,05H,00H,00H,00H,00H;
        DB 00H,00H,E0H,01H,7EH,00H,00H,20H;
        DB 61H,98H,43H,04H,81H,A2H,28H,02H;
        DB E1H,70H,95H,C3H,45H,04H,26H,38H;
        DB 4EH,05H,00H,00H,00H,00H,00H,00H;
        DB E0H,01H,7EH,00H,00H,00H,00H,80H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,F0H,1FH,E6H,C3H;
        DB E7H,FFH,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,F0H,EFH,FFH,7EH,60H,F0H;
        DB 07H,00H,00H,00H,00H,00H,01H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB F0H,EFH,FFH,7EH,60H,90H,07H,00H;
        DB 00H,00H,00H,00H,03H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,78H,00H;
        DB F0H,00H,00H,18H,06H,00H,00H,00H;
        DB 00H,38H,03H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,F8H,03H,00H,00H;
        DB 00H,00H,07H,00H,00H,00H,00H,26H;
        DB 02H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,C0H,0FH,00H,00H,00H,00H,00H;
        DB 1EH,00H,00H,00H,00H,26H,02H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,C0H;
        DB 0FH,00H,00H,00H,00H,00H,1CH,00H;
        DB 00H,00H,00H,1EH,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,60H,00H,00H;
        DB 00H,00H,00H,00H,F0H,00H,00H,00H;
        DB E0H,04H,04H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,20H,00H,00H,00H,00H;
        DB 00H,00H,D8H,01H,00H,00H,A6H,08H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,20H,00H,00H,00H,00H,00H,00H;
        DB A8H,01H,00H,00H,2AH,09H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,20H;
        DB 00H,00H,00H,00H,00H,3FH,82H,01H;
        DB 00H,30H,36H,01H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,60H,00H,00H;
        DB C0H,FFH,07H,F3H,CAH,03H,00H,48H;
        DB 04H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,18H,00H,00H,E0H,80H;
        DB 7FH,43H,0BH,02H,00H,89H,04H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,18H,00H,00H,E0H,80H,FFH,43H;
        DB 5FH,02H,00H,89H,04H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,1EH;
        DB 00H,9CH,36H,00H,E0H,87H,DFH,0EH;
        DB 00H,89H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,03H,00H,EFH;
        DB F7H,01H,00H,03H,80H,0EH,20H,73H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,03H,00H,69H,90H,01H;
        DB 00H,03H,80H,0FH,A0H,02H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB C0H,01H,00H,15H,C0H,01H,00H,00H;
        DB E0H,03H,64H,02H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,E0H,00H;
        DB C0H,00H,E0H,00H,00H,04H,00H,03H;
        DB 42H,04H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,20H,00H,C0H,02H;
        DB E0H,00H,00H,04H,00H,03H,42H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,A0H,00H,70H,01H,20H,00H;
        DB 78H,04H,07H,0EH,82H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB B0H,00H,14H,01H,20H,30H,80H,87H;
        DB 07H,1CH,3EH,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,B0H,60H;
        DB D7H,01H,20H,30H,00H,07H,01H,1CH;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,70H,08H,77H,00H;
        DB 20H,30H,00H,07H,01H,1CH,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,70H,00H,33H,00H,20H,30H;
        DB 00H,0CH,00H,1FH,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 30H,E0H,0DH,00H,E0H,00H,00H,0CH;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,F0H,00H,00H,00H,00H,30H,21H;
        DB 0DH,00H,E0H,00H,00H,0CH,00H,00H;
        DB 00H,00H,C0H,03H,00H,00H,E0H,01H;
        DB 00H,00H,00H,00H,1EH,E0H,E1H,91H;
        DB 00H,00H,00H,00H,0CH,38H,07H,00H;
        DB F0H,0FH,00H,0CH,1FH,00H,00H,00H;
        DB 40H,02H,00H,00H,20H,01H,00H,00H;
        DB 00H,00H,12H,20H,91H,90H,3CH,00H;
        DB 00H,00H,0EH,0CH,0BH,00H,00H,01H;
        DB 00H,0FH,70H,00H,00H,00H,40H,02H;
        DB 00H,00H,20H,01H,00H,00H,00H,00H;
        DB 12H,20H,49H,F0H,24H,00H,00H,00H;
        DB 0EH,2CH,01H,00H,00H,00H,80H,07H;
        DB E0H,00H,00H,00H,40H,02H,00H,00H;
        DB 20H,01H,00H,00H,00H,00H,12H,20H;
        DB 29H,00H,24H,00H,00H,00H,2EH,0CH;
        DB 05H,00H,00H,00H,80H,07H,E0H,00H;
        DB 00H,00H,40H,02H,C0H,07H,2FH,79H;
        DB E7H,01H,1FH,F0H,12H,20H,15H,F0H;
        DB E6H,00H,00H,00H,1EH,FDH,3DH,00H;
        DB 00H,00H,C0H,07H,80H,01H,00H,00H;
        DB 40H,02H,30H,88H,31H,C9H,18H,C2H;
        DB 60H,18H,13H,20H,13H,90H,82H,00H;
        DB 00H,00H,0FH,40H,14H,00H,00H,00H;
        DB E0H,00H,00H,00H,00H,00H,40H,02H;
        DB 10H,90H,20H,49H,08H,44H,40H,08H;
        DB 12H,20H,09H,90H,82H,00H,00H,00H;
        DB D7H,40H,56H,00H,00H,00H,E0H,00H;
        DB 00H,00H,00H,00H,40H,02H,88H,5FH;
        DB 1CH,A9H,63H,24H,8EH,C4H,11H,20H;
        DB 10H,90H,E6H,00H,00H,00H,47H,61H;
        DB 14H,00H,00H,00H,00H,00H,00H,00H;
        DB 20H,00H,40H,02H,48H,40H,22H,49H;
        DB 92H,24H,91H,24H,12H,20H,26H,90H;
        DB 24H,00H,00H,00H,A6H,7DH,1CH,00H;
        DB 00H,00H,00H,00H,00H,00H,40H,00H;
        DB 40H,02H,48H,40H,22H,49H,92H,24H;
        DB 91H,24H,12H,20H,25H,90H,24H,00H;
        DB 00H,00H,A6H,E5H,16H,00H,00H,00H;
        DB 00H,00H,00H,0CH,40H,00H,40H,02H;
        DB 48H,5EH,22H,49H,92H,24H,91H,24H;
        DB 12H,20H,49H,90H,24H,00H,00H,00H;
        DB 36H,E5H,3AH,00H,00H,00H,00H,00H;
        DB 00H,0CH,40H,00H,40H,FEH,88H,53H;
        DB 3CH,49H,92H,24H,8EH,C4H,13H,20H;
        DB 91H,90H,E4H,00H,00H,00H,66H,E3H;
        DB 06H,00H,00H,00H,00H,00H,00H,0CH;
        DB 40H,00H,40H,80H,10H,88H,20H,49H;
        DB 92H,44H,40H,08H,12H,20H,91H,90H;
        DB 84H,00H,00H,00H,0EH,C3H,02H,00H;
        DB 00H,00H,00H,00H,00H,0CH,60H,00H;
        DB 40H,80H,30H,8CH,31H,49H,92H,C4H;
        DB 60H,18H,13H,20H,21H,91H,8CH,00H;
        DB 00H,00H,1EH,C2H,02H,00H,00H,00H;
        DB 00H,00H,00H,0CH,60H,00H,C0H,FFH;
        DB C0H,03H,EFH,79H,9EH,07H,1FH,F0H;
        DB 1EH,E0H,C1H,F3H,F8H,00H,00H,00H;
        DB EEH,C2H,01H,00H,00H,00H,00H,00H;
        DB 00H,0CH,20H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,6CH,C7H;
        DB 01H,00H,00H,00H,20H,00H,00H,1EH;
        DB 20H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,8CH,C7H,01H,00H;
        DB 00H,00H,20H,00H,00H,1EH,20H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,2CH,43H,00H,00H,00H,00H;
        DB 18H,00H,00H,1EH,20H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 0CH,43H,00H,00H,00H,00H,00H,00H;
        DB 00H,1EH,22H,38H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,6CH,47H;
        DB 00H,00H,00H,00H,00H,00H,00H,1EH;
        DB 02H,44H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,4CH,47H,00H,00H;
        DB 00H,00H,00H,00H,00H,1EH,02H,44H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,4CH,7DH,00H,00H,00H,00H;
        DB 00H,00H,00H,0EH,00H,04H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB CCH,DCH,01H,00H,00H,00H,00H,00H;
        DB 00H,0EH,00H,04H,03H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,CCH,DCH;
        DB 01H,00H,00H,00H,00H,00H,00H,0EH;
        DB 00H,84H,01H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,FCH,DCH,01H,00H;
        DB 00H,00H,00H,00H,00H,0EH,00H,CCH;
        DB 0DH,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,DCH,F8H,01H,00H,00H,00H;
        DB 00H,00H,00H,0EH,00H,40H,07H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,80H;
        DB 5CH,E4H,01H,00H,00H,00H,00H,00H;
        DB 00H,03H,00H,00H,03H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,80H,BCH,E6H;
        DB 01H,00H,00H,00H,00H,00H,00H,03H;
        DB 7CH,00H,71H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,80H,BCH,E4H,07H,00H;
        DB 00H,00H,00H,00H,00H,03H,FEH,00H;
        DB 88H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,98H,F0H,FDH,0FH,00H,00H,00H;
        DB 00H,00H,80H,03H,C2H,00H,88H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,98H;
        DB F0H,FDH,1FH,00H,00H,00H,00H,00H;
        DB 80H,03H,C3H,00H,88H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,98H,20H,67H;
        DB 30H,00H,00H,00H,00H,00H,E0H,80H;
        DB C1H,00H,78H,02H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,98H,01H,7FH,70H,00H;
        DB 00H,00H,FCH,00H,70H,C0H,70H,00H;
        DB 00H,03H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,98H,01H,7FH,E0H,00H,00H,00H;
        DB FCH,00H,70H,60H,18H,00H,80H,07H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,10H;
        DB 03H,FCH,81H,01H,00H,00H,00H,00H;
        DB 18H,30H,08H,00H,80H,3CH,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,10H,0FH,C0H;
        DB 01H,03H,00H,00H,00H,00H,0FH,18H;
        DB 0EH,00H,00H,24H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,70H,1EH,00H,06H,06H;
        DB 00H,00H,00H,80H,0FH,0CH,03H,00H;
        DB 00H,B0H,03H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,70H,1EH,00H,06H,04H,00H,00H;
        DB 00H,80H,0FH,06H,01H,00H,00H,D8H;
        DB 07H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,60H;
        DB 0CH,00H,0CH,0CH,00H,00H,00H,F0H;
        DB FFH,DFH,01H,00H,00H,40H,04H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,80H,00H,00H;
        DB 38H,18H,00H,00H,00H,F8H,F6H,FFH;
        DB 01H,00H,00H,E0H,07H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,80H,00H,00H,30H,18H;
        DB 00H,00H,00H,F8H,F6H,FFH,01H,00H;
        DB 00H,20H,80H,01H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,0FH,00H,20H,70H,00H,00H;
        DB 00H,CCH,07H,E0H,03H,00H,00H,00H;
        DB C0H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,60H,70H,00H,00H,00H,C4H;
        DB 07H,C0H,03H,00H,00H,00H,60H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB C0H,F3H,FFH,03H,00H,8CH,00H,00H;
        DB 03H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,C0H,F3H;
        DB FFH,03H,00H,8CH,00H,00H,03H,00H;
        DB 00H,00H,10H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,C6H,7FH,10H,FCH;
        DB 01H,FCH,00H,00H,06H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,F8H,FFH,03H,E0H,00H,00H,F8H;
        DB FFH,00H,1CH,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,F8H;
        DB FFH,03H,E0H,00H,00H,F8H,FFH,00H;
        DB 1CH,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,FFH,0FH,00H;
        DB E0H,00H,00H,BCH,F1H,0FH,38H,00H;
        DB 00H,00H,00H,00H,30H,00H,00H,00H;
        DB 00H,80H,01H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,FFH,03H,00H,3EH,00H;
        DB 00H,F7H,F8H,0FH,38H,00H,00H,00H;
        DB 00H,00H,08H,00H,00H,00H,00H,60H;
        DB 00H,00H,00H,60H,00H,00H,00H,00H;
        DB E0H,E1H,01H,80H,7FH,00H,80H,7FH;
        DB FCH,00H,78H,00H,00H,00H,00H,00H;
        DB 04H,00H,E0H,01H,00H,20H,00H,00H;
        DB C0H,11H,00H,00H,00H,00H,E0H,E1H;
        DB 01H,80H,7FH,00H,80H,7FH,FEH,00H;
        DB 78H,00H,00H,00H,00H,00H,04H,00H;
        DB 90H,10H,00H,20H,00H,00H,20H,09H;
        DB 00H,00H,00H,00H,F0H,E1H,03H,F0H;
        DB E0H,00H,C0H,3FH,07H,00H,60H,00H;
        DB 00H,00H,00H,00H,34H,11H,90H,08H;
        DB 67H,A3H,71H,36H,10H,66H,04H,00H;
        DB 00H,00H,FEH,81H,03H,E0H,C1H,01H;
        DB FCH,BFH,01H,00H,E0H,01H,00H,00H;
        DB 00H,00H,ACH,13H,10H,BCH,D4H,52H;
        DB 49H,2BH,10H,56H,04H,00H,00H,00H;
        DB FEH,81H,03H,E0H,01H,03H,FCH,9FH;
        DB 01H,00H,E0H,01H,00H,00H,00H,00H;
        DB 26H,12H,20H,48H,22H,32H,25H,26H;
        DB 30H,42H,06H,00H,00H,00H,FFH,81H;
        DB 03H,F8H,01H,FFH,7FH,CFH,00H,03H;
        DB E0H,03H,00H,00H,00H,00H,22H,16H;
        DB 40H,C8H,21H,12H,1DH,22H,00H,22H;
        DB 02H,00H,00H,80H,FFH,80H,03H,00H;
        DB E7H,EFH,FFH,F7H,FFH,03H,C0H,07H;
        DB 00H,00H,00H,00H,12H,0CH,80H,64H;
        DB 24H,91H,44H,12H,00H,22H,02H,00H;
        DB 00H,80H,FFH,80H,03H,00H,E7H,EFH;
        DB FFH,F7H,FFH,03H,C0H,0FH,00H,00H;
        DB 00H,00H,12H,0CH,82H,54H,12H,89H;
        DB 26H,51H,00H,21H,0BH,00H,00H,E0H;
        DB FDH,C2H,01H,00H,FEH,7FH,FAH,C3H;
        DB 01H,00H,C0H,1FH,00H,00H,00H,00H;
        DB 0EH,04H,42H,CCH,F1H,88H,1DH,31H;
        DB 80H,E7H,06H,00H,00H,F8H,D3H,E2H;
        DB 01H,F7H,1EH,FCH,7BH,F0H,00H,00H;
        DB C0H,1FH,00H,00H,00H,00H,00H,04H;
        DB 3CH,00H,10H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,FEH,D3H,FAH,01H,FCH;
        DB 3FH,8CH,3FH,F0H,00H,0EH,C0H,1FH;
        DB 00H,00H,00H,00H,00H,02H,00H,00H;
        DB 10H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,FEH,D3H,FAH,01H,FCH,3FH,8CH;
        DB 3FH,F0H,00H,0EH,C0H,1FH,00H,00H;
        DB 00H,00H,00H,01H,00H,00H,08H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,9FH;
        DB DFH,FCH,01H,FCH,FFH,81H,FFH,C0H;
        DB 00H,00H,C0H,1FH,00H,00H,00H,00H;
        DB E0H,00H,00H,00H,1CH,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,9FH,FEH,F9H;
        DB 01H,FFH,FEH,01H,FCH,C4H,0FH,00H;
        DB 80H,1FH,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,9FH,FEH,F9H,01H,FFH;
        DB FEH,01H,FCH,C4H,0FH,00H,80H,1FH;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 80H,1FH,3CH,7AH,C0H,EFH,01H,01H;
        DB E0H,7FH,71H,00H,80H,7FH,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,C0H,1FH;
        DB FCH,7AH,F0H,80H,01H,80H,C3H,87H;
        DB F7H,03H,80H,FFH,00H,00H,00H,00H;
        DB 00H,00H,00H,C0H,83H,C1H,E1H,30H;
        DB 00H,00H,00H,00H,C0H,1FH,FCH,3FH;
        DB 0CH,00H,0FH,00H,3CH,0FH,F0H,03H;
        DB 80H,FFH,03H,00H,00H,00H,00H,00H;
        DB 00H,30H,44H,62H,32H,49H,00H,00H;
        DB 00H,00H,C0H,1FH,FCH,3FH,0CH,00H;
        DB 0FH,00H,3CH,0FH,F0H,03H,80H,FFH;
        DB 03H,00H,00H,00H,00H,00H,00H,C8H;
        DB 05H,22H,12H,41H,00H,00H,00H,00H;
        DB C0H,1FH,FDH,7FH,0CH,00H,00H,00H;
        DB 80H,0FH,00H,FFH,FFH,FFH,03H,00H;
        DB 00H,00H,00H,00H,00H,24H,05H,12H;
        DB 0AH,41H,00H,00H,00H,00H,C0H,7FH;
        DB FCH,FFH,FFH,1FH,06H,00H,00H,0FH;
        DB F8H,FFH,FFH,FFH,03H,00H,00H,00H;
        DB 00H,00H,00H,94H,02H,11H,0AH,21H;
        DB 00H,00H,00H,00H,C0H,7FH,FCH,FFH;
        DB FFH,1FH,06H,00H,00H,0FH,F8H,FFH;
        DB FFH,FFH,03H,00H,00H,00H,00H,00H;
        DB 00H,F4H,81H,10H,0AH,11H,00H,00H;
        DB 00H,00H,F0H,FFH,FFH,00H,F0H,FFH;
        DB FFH,FFH,FFH,FFH,FFH,7FH,00H,FFH;
        DB 03H,00H,00H,00H,00H,00H,00H,04H;
        DB 40H,10H,89H,08H,00H,00H,00H,00H;
        DB F0H,FFH,FFH,01H,00H,F0H,FFH,FFH;
        DB FFH,FFH,0FH,00H,80H,FFH,FFH,FFH;
        DB 7FH,00H,00H,00H,00H,0CH,22H,91H;
        DB C9H,24H,00H,00H,00H,00H,F0H,FFH;
        DB FFH,07H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,C0H,FFH,FFH,FFH,7FH,00H;
        DB 00H,00H,00H,F8H,F1H,E0H,70H,1EH;
        DB 00H,00H,00H,00H,F8H,FFH,FFH,1FH;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB E0H,01H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,7FH,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,F8H,01H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,FEH,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,1FH,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,FEH,0FH,00H,00H,00H,00H,00H;
        DB 00H,E0H,1FH,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,E0H;
        DB 7FH,00H,00H,00H,00H,00H,80H,FFH;
        DB 01H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,F0H,FFH;
        DB FFH,FFH,FFH,FFH,FFH,1FH,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,F0H,FFH,FFH,FFH;
        DB FFH,FFH,FFH,1FH,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,F0H,FFH,FFH,FFH,FFH;
        DB FFH,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;
        DB 00H,00H,00H,00H,00H,00H,00H,00H;

        END
